@@ -5,6 +5,7 @@ from pydantic import validate_arguments
 
 from ..cache import cache
 from ..core import BaseClient
+from ..errors import RequestError, ServerError
 
 PATH = "/users/{user_uuid}/institutions"
 
@@ -25,7 +26,11 @@ class BaseInstitutionsResource(ABC):
         async with self._client.session() as session:
             response = await session.get(PATH.format(user_uuid=user_uuid))
 
-        assert response.status_code == 200, response.text
+        if response.status_code // 100 == 5:
+            raise ServerError(response.text)
+
+        if response.status_code // 100 == 4:
+            raise RequestError(response.text)
 
         institutions_response: InstitutionsResponse = response.json()
         return institutions_response["institutions"]
